﻿using Syncfusion.UI.Xaml.Grid;
using Syncfusion.UI.Xaml.Grid.Cells;
using Syncfusion.UI.Xaml.Grid.Helpers;
using Syncfusion.UI.Xaml.ScrollAxis;
using System;
using System.Reflection;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.Primitives;
using System.Windows.Input;

namespace SfColumns
{
    public class TestTextRenderer : GridVirtualizingCellRenderer<TextBlock, TestTextBox>
    {
        protected override TextBlock OnCreateDisplayUIElement()
        {
            return new TextBlock();
        }

        protected override TestTextBox OnCreateEditUIElement()
        {
            return new TestTextBox();
        }

        public override void OnInitializeEditElement(DataColumnBase dataColumn, TestTextBox uiElement, object dataContext)
        {
            base.OnInitializeEditElement(dataColumn, uiElement, dataContext);

            uiElement.SetBinding(TextBox.TextProperty, dataColumn.GridColumn.ValueBinding);

            VisualContainer.SetWantsMouseInput(uiElement, true);
            FocusManagerHelper.SetFocusedElement(uiElement, true);
        }

        protected override void OnEditElementLoaded(object sender, RoutedEventArgs e)
        {
            base.OnEditElementLoaded(sender, e);
            var customTextBox = (TestTextBox)sender;
            customTextBox.Focus();
        }
    }

    public class TestCheckBoxRenderer : GridVirtualizingCellRenderer<TestCheckBox, TestCheckBox>
    {
        public TestCheckBoxRenderer()
        {
            SupportsRenderOptimization = false;
            IsEditable = false;
        }

        public override void OnInitializeEditElement(DataColumnBase dataColumn, TestCheckBox uiElement, object dataContext)
        {
            base.OnInitializeEditElement(dataColumn, uiElement, dataContext);
            var column = dataColumn.GridColumn;
            uiElement.FocusVisualStyle = null;
            uiElement.SetValue(FrameworkElement.VerticalAlignmentProperty, column.VerticalAlignment);
            var checkBoxColumn = column as GridCheckBoxColumn;
            if (checkBoxColumn == null)
                return;
            uiElement.SetValue(FrameworkElement.HorizontalAlignmentProperty, checkBoxColumn.HorizontalAlignment);

        }
        public override void OnUpdateEditBinding(DataColumnBase dataColumn, TestCheckBox element, object dataContext)
        {
            OnInitializeEditElement(dataColumn, element, dataContext);
        }
    }
}
